@@ -59,4 +59,4 @@ for component in cdf.components():
 
 if __name__ == '__main__':
     #emora.precache_transitions()
-    cdf.run(debugging=True)
\ No newline at end of file
+    cdf.run(debugging=False)
\ No newline at end of file
