@@ -253,7 +253,7 @@ d = \
     "relative": ["aunt", "uncle", "grandparent", "niece", "nephew", "cousin"],
     "inlaw": ["father in law", "mother in law", "sister in law", "brother in law", "daughter in law", "son in law"],
 
-    "_life events": [
+    "_old_life events": [
         "_romantic event",
         "_end romantic event",
         "_new life",
@@ -827,6 +827,29 @@ d = \
         "dessert",
         "shower",
         "pajamas"
+    ],
+    "_insults":[
+        "bitch",
+        "shit",
+        "shitty",
+        "dumb",
+        "stupid",
+        "idiotic",
+        "idiot",
+        "annoying",
+        "frustrating",
+        "retarded",
+        "imbecile",
+        "irritating",
+        "infuriating",
+        "exasperating",
+        "maddening",
+        "tiresome",
+        "horrible",
+        "worst",
+        "garbage",
+        "worthless",
+        "useless"
     ]
 }
 
